Chapter 1: Strong Lensing
=========================

In chapter 1, we introduce you to strong gravitational lensing and the core **PyAutoLens** API.

**Binder** links to every tutorial are included.

The chapter contains the following tutorials:

`Tutorial 0: Visualization <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_0_visualization.ipynb>`_
- Setting up **PyAutoLens**'s visualization library.

`Tutorial 1: Grids <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_1_grids.ipynb>`_
- Uniform grids of (y,x) coordinates used for ray-tracing.

`Tutorial 2: Profiles <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_2_profiles.ipynb>`_
- Analytic profiles representing light and mass distributions.

`Tutorial 3: galaxies <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_3_galaxies.ipynb>`_
- Making galaxy objects out of light and mass profile.

`Tutorial 4: Ray Tracing <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_5_ray_tracing.ipynb>`_
- Using Grids and galaxies to perform strong lens ray-tracing!

`Tutorial 5: More Ray Tracing <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_5_more_ray_tracing.ipynb>`_
- Advanced strong lens ray-tracing.

`Tutorial 8: Summary <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_1_introduction/tutorial_8_summary.ipynb>`_
- A summary of the chapter.